@@ -97,7 +97,7 @@ class Column(object):
 
     @property
     def has_default(self):
-        return bool(self.default)
+        return self.default is not None
 
     @property
     def is_primary_key(self):
@@ -146,6 +146,23 @@ class Ascii(Column):
 class Text(Column):
     db_type = 'text'
 
+    def __init__(self, *args, **kwargs):
+        self.min_length = kwargs.pop('min_length', 1 if kwargs.get('required', True) else None)
+        self.max_length = kwargs.pop('max_length', None)
+        super(Text, self).__init__(*args, **kwargs)
+
+    def validate(self, value):
+        value = super(Text, self).validate(value)
+        if not isinstance(value, (basestring, bytearray)) and value is not None:
+            raise ValidationError('{} is not a string'.format(type(value)))
+        if self.max_length:
+            if len(value) > self.max_length:
+                raise ValidationError('{} is longer than {} characters'.format(self.column_name, self.max_length))
+        if self.min_length:
+            if len(value) < self.min_length:
+                raise ValidationError('{} is shorter than {} characters'.format(self.column_name, self.min_length))
+        return value
+
 class Integer(Column):
     db_type = 'int'
 
